/*     */ package org.apache.batik.util.gui.resource;
/*     */ 
/*     */ import java.net.URL;
/*     */ import java.util.Iterator;
/*     */ import java.util.List;
/*     */ import java.util.MissingResourceException;
/*     */ import java.util.ResourceBundle;
/*     */ import javax.swing.AbstractButton;
/*     */ import javax.swing.Action;
/*     */ import javax.swing.ButtonGroup;
/*     */ import javax.swing.ImageIcon;
/*     */ import javax.swing.JCheckBoxMenuItem;
/*     */ import javax.swing.JComponent;
/*     */ import javax.swing.JMenu;
/*     */ import javax.swing.JMenuBar;
/*     */ import javax.swing.JMenuItem;
/*     */ import javax.swing.JRadioButtonMenuItem;
/*     */ import javax.swing.JSeparator;
/*     */ import javax.swing.KeyStroke;
/*     */ import org.apache.batik.util.resources.ResourceFormatException;
/*     */ import org.apache.batik.util.resources.ResourceManager;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class MenuFactory
/*     */   extends ResourceManager
/*     */ {
/*     */   private static final String TYPE_MENU = "MENU";
/*     */   private static final String TYPE_ITEM = "ITEM";
/*     */   private static final String TYPE_RADIO = "RADIO";
/*     */   private static final String TYPE_CHECK = "CHECK";
/*     */   private static final String SEPARATOR = "-";
/*     */   private static final String TYPE_SUFFIX = ".type";
/*     */   private static final String TEXT_SUFFIX = ".text";
/*     */   private static final String MNEMONIC_SUFFIX = ".mnemonic";
/*     */   private static final String ACCELERATOR_SUFFIX = ".accelerator";
/*     */   private static final String ACTION_SUFFIX = ".action";
/*     */   private static final String SELECTED_SUFFIX = ".selected";
/*     */   private static final String ENABLED_SUFFIX = ".enabled";
/*     */   private static final String ICON_SUFFIX = ".icon";
/*     */   private ActionMap actions;
/*     */   private ButtonGroup buttonGroup;
/*     */   
/*     */   public MenuFactory(ResourceBundle rb, ActionMap am) {
/* 106 */     super(rb);
/* 107 */     this.actions = am;
/* 108 */     this.buttonGroup = null;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 127 */   public JMenuBar createJMenuBar(String name) throws MissingResourceException, ResourceFormatException, MissingListenerException { return createJMenuBar(name, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public JMenuBar createJMenuBar(String name, String specialization) throws MissingResourceException, ResourceFormatException, MissingListenerException {
/* 147 */     JMenuBar result = new JMenuBar();
/* 148 */     List menus = getSpecializedStringList(name, specialization);
/* 149 */     Iterator it = menus.iterator();
/*     */     
/* 151 */     while (it.hasNext()) {
/* 152 */       result.add(createJMenuComponent((String)it.next(), specialization));
/*     */     }
/* 154 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected String getSpecializedString(String name, String specialization) {
/*     */     String str;
/*     */     try {
/* 166 */       str = getString(name + '.' + specialization);
/*     */     } catch (MissingResourceException mre) {
/* 168 */       str = getString(name);
/*     */     } 
/* 170 */     return str;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected List getSpecializedStringList(String name, String specialization) {
/*     */     List list;
/*     */     try {
/* 183 */       list = getStringList(name + '.' + specialization);
/*     */     } catch (MissingResourceException mre) {
/* 185 */       list = getStringList(name);
/*     */     } 
/* 187 */     return list;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected boolean getSpecializedBoolean(String name, String specialization) {
/*     */     boolean bool;
/*     */     try {
/* 200 */       bool = getBoolean(name + '.' + specialization);
/*     */     } catch (MissingResourceException mre) {
/* 202 */       bool = getBoolean(name);
/*     */     } 
/* 204 */     return bool;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected JComponent createJMenuComponent(String name, String specialization) throws MissingResourceException, ResourceFormatException, MissingListenerException {
/* 223 */     if (name.equals("-")) {
/* 224 */       this.buttonGroup = null;
/* 225 */       return new JSeparator();
/*     */     } 
/* 227 */     String type = getSpecializedString(name + ".type", specialization);
/*     */     
/* 229 */     JComponent item = null;
/*     */     
/* 231 */     if (type.equals("RADIO")) {
/* 232 */       if (this.buttonGroup == null) {
/* 233 */         this.buttonGroup = new ButtonGroup();
/*     */       }
/*     */     } else {
/* 236 */       this.buttonGroup = null;
/*     */     } 
/*     */     
/* 239 */     if (type.equals("MENU")) {
/* 240 */       item = createJMenu(name, specialization);
/* 241 */     } else if (type.equals("ITEM")) {
/* 242 */       item = createJMenuItem(name, specialization);
/* 243 */     } else if (type.equals("RADIO")) {
/* 244 */       item = createJRadioButtonMenuItem(name, specialization);
/* 245 */       this.buttonGroup.add((AbstractButton)item);
/* 246 */     } else if (type.equals("CHECK")) {
/* 247 */       item = createJCheckBoxMenuItem(name, specialization);
/*     */     } else {
/* 249 */       throw new ResourceFormatException("Malformed resource", this.bundle.getClass().getName(), name + ".type");
/*     */     } 
/*     */ 
/*     */ 
/*     */     
/* 254 */     return item;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 273 */   public JMenu createJMenu(String name) throws MissingResourceException, ResourceFormatException, MissingListenerException { return createJMenu(name, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public JMenu createJMenu(String name, String specialization) throws MissingResourceException, ResourceFormatException, MissingListenerException {
/* 293 */     JMenu result = new JMenu(getSpecializedString(name + ".text", specialization));
/*     */     
/* 295 */     initializeJMenuItem(result, name, specialization);
/*     */     
/* 297 */     List items = getSpecializedStringList(name, specialization);
/* 298 */     Iterator it = items.iterator();
/*     */     
/* 300 */     while (it.hasNext()) {
/* 301 */       result.add(createJMenuComponent((String)it.next(), specialization));
/*     */     }
/* 303 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 322 */   public JMenuItem createJMenuItem(String name) throws MissingResourceException, ResourceFormatException, MissingListenerException { return createJMenuItem(name, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public JMenuItem createJMenuItem(String name, String specialization) throws MissingResourceException, ResourceFormatException, MissingListenerException {
/* 342 */     JMenuItem result = new JMenuItem(getSpecializedString(name + ".text", specialization));
/*     */     
/* 344 */     initializeJMenuItem(result, name, specialization);
/* 345 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 364 */   public JRadioButtonMenuItem createJRadioButtonMenuItem(String name) throws MissingResourceException, ResourceFormatException, MissingListenerException { return createJRadioButtonMenuItem(name, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public JRadioButtonMenuItem createJRadioButtonMenuItem(String name, String specialization) throws MissingResourceException, ResourceFormatException, MissingListenerException {
/* 386 */     JRadioButtonMenuItem result = new JRadioButtonMenuItem(getSpecializedString(name + ".text", specialization));
/*     */     
/* 388 */     initializeJMenuItem(result, name, specialization);
/*     */ 
/*     */     
/*     */     try {
/* 392 */       result.setSelected(getSpecializedBoolean(name + ".selected", specialization));
/*     */     }
/* 394 */     catch (MissingResourceException e) {}
/*     */ 
/*     */     
/* 397 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 416 */   public JCheckBoxMenuItem createJCheckBoxMenuItem(String name) throws MissingResourceException, ResourceFormatException, MissingListenerException { return createJCheckBoxMenuItem(name, null); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public JCheckBoxMenuItem createJCheckBoxMenuItem(String name, String specialization) throws MissingResourceException, ResourceFormatException, MissingListenerException {
/* 438 */     JCheckBoxMenuItem result = new JCheckBoxMenuItem(getSpecializedString(name + ".text", specialization));
/*     */     
/* 440 */     initializeJMenuItem(result, name, specialization);
/*     */ 
/*     */     
/*     */     try {
/* 444 */       result.setSelected(getSpecializedBoolean(name + ".selected", specialization));
/*     */     }
/* 446 */     catch (MissingResourceException e) {}
/*     */ 
/*     */     
/* 449 */     return result;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void initializeJMenuItem(JMenuItem item, String name, String specialization) throws ResourceFormatException, MissingListenerException {
/*     */     try {
/* 468 */       Action a = this.actions.getAction(getSpecializedString(name + ".action", specialization));
/*     */       
/* 470 */       if (a == null) {
/* 471 */         throw new MissingListenerException("", "Action", name + ".action");
/*     */       }
/*     */       
/* 474 */       item.setAction(a);
/* 475 */       item.setText(getSpecializedString(name + ".text", specialization));
/*     */       
/* 477 */       if (a instanceof JComponentModifier) {
/* 478 */         ((JComponentModifier)a).addJComponent(item);
/*     */       }
/* 480 */     } catch (MissingResourceException e) {}
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 485 */       String s = getSpecializedString(name + ".icon", specialization);
/* 486 */       URL url = this.actions.getClass().getResource(s);
/* 487 */       if (url != null) {
/* 488 */         item.setIcon(new ImageIcon(url));
/*     */       }
/* 490 */     } catch (MissingResourceException e) {}
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 495 */       String str = getSpecializedString(name + ".mnemonic", specialization);
/*     */       
/* 497 */       if (str.length() == 1) {
/* 498 */         item.setMnemonic(str.charAt(0));
/*     */       } else {
/* 500 */         throw new ResourceFormatException("Malformed mnemonic", this.bundle.getClass().getName(), name + ".mnemonic");
/*     */       }
/*     */     
/*     */     }
/* 504 */     catch (MissingResourceException e) {}
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 509 */       if (!(item instanceof JMenu)) {
/* 510 */         String str = getSpecializedString(name + ".accelerator", specialization);
/*     */         
/* 512 */         KeyStroke ks = KeyStroke.getKeyStroke(str);
/* 513 */         if (ks != null) {
/* 514 */           item.setAccelerator(ks);
/*     */         } else {
/* 516 */           throw new ResourceFormatException("Malformed accelerator", this.bundle.getClass().getName(), name + ".accelerator");
/*     */         }
/*     */       
/*     */       }
/*     */     
/*     */     }
/* 522 */     catch (MissingResourceException e) {}
/*     */ 
/*     */ 
/*     */     
/*     */     try {
/* 527 */       item.setEnabled(getSpecializedBoolean(name + ".enabled", specialization));
/*     */     }
/* 529 */     catch (MissingResourceException e) {}
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-gui-util.jar!\org\apache\bati\\util\gui\resource\MenuFactory.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */